@@ -9,7 +9,7 @@ setup(
     author='Certbot Project',
     author_email='certbot-dev@eff.org',
     license='Apache License 2.0',
-    python_requires='>=3.9',
+    python_requires='>=3.9.2',
     classifiers=[
         'Development Status :: 5 - Production/Stable',
         'Intended Audience :: Developers',
